@@ -23,38 +23,42 @@ use std::collections::BTreeSet;
 use xor_name::XorName;
 
 impl Core {
-    pub(crate) fn handle_dkg_start(
-        &mut self,
+    pub(crate) async fn handle_dkg_start(
+        &self,
         session_id: DkgSessionId,
         elder_candidates: ElderCandidates,
     ) -> Result<Vec<Command>> {
         trace!("Received DkgStart for {:?}", elder_candidates);
-        self.dkg_voter.start(
-            &self.node,
-            session_id,
-            elder_candidates,
-            *self.section_chain().last_key(),
-        )
+        self.dkg_voter
+            .start(
+                &self.node,
+                session_id,
+                elder_candidates,
+                *self.section_chain().last_key(),
+            )
+            .await
     }
 
-    pub(crate) fn handle_dkg_message(
-        &mut self,
+    pub(crate) async fn handle_dkg_message(
+        &self,
         session_id: DkgSessionId,
         message: DkgMessage,
         sender: XorName,
     ) -> Result<Vec<Command>> {
         trace!("handle DKG message {:?} from {}", message, sender);
 
-        self.dkg_voter.process_message(
-            &self.node,
-            &session_id,
-            message,
-            *self.section_chain().last_key(),
-        )
+        self.dkg_voter
+            .process_message(
+                &self.node,
+                &session_id,
+                message,
+                *self.section_chain().last_key(),
+            )
+            .await
     }
 
     pub(crate) fn handle_dkg_failure_observation(
-        &mut self,
+        &self,
         session_id: DkgSessionId,
         failed_participants: &BTreeSet<XorName>,
         signed: DkgFailureSig,
@@ -132,7 +136,7 @@ impl Core {
         result
     }
 
-    pub(crate) fn handle_dkg_failure(&mut self, failure_set: DkgFailureSigSet) -> Result<Command> {
+    pub(crate) fn handle_dkg_failure(&self, failure_set: DkgFailureSigSet) -> Result<Command> {
         let node_msg = SystemMsg::DkgFailureAgreement(failure_set);
         self.send_message_to_our_elders(node_msg)
     }
